@@ -855,6 +855,8 @@ def get_random_generator(seed=None):
     """
     Return a random generator (using the seed provided if available)
     """
+    if isinstance(seed, np.random.Generator):
+        return seed
     return np.random.Generator(np.random.PCG64(seed))
 
 
